@@ -26,13 +26,14 @@ import os
 import logging
 logger = logging.getLogger('camelot.admin.application_admin')
 
+from PyQt4.QtCore import Qt
 from PyQt4 import QtCore, QtGui
 
-from camelot.view.model_thread import model_function
-from camelot.core.backup import BackupMechanism
+from camelot.admin.action import list_action, application_action
 from camelot.core.utils import ugettext_lazy as _
 from camelot.view import art
 from camelot.view import database_selection
+from camelot.view.model_thread import model_function
 
 _application_admin_ = []
 
@@ -81,11 +82,6 @@ methods :
 .. attribute:: version
     
     A string with the version of the application
-
-.. attribute:: backup_mechanism
-
-    A subclass of :class:`camelot.core.backup.BackupMechanism` that enables 
-    the application to perform backups an restores.
     
 .. attribute:: database_profile_wizard
     
@@ -96,9 +92,12 @@ methods :
 
     if this is set to True, present the user with a database selection
     wizard prior to starting the application.  Defaults to :keyword:`False`.
+    
+When the same action is returned in the :meth:`get_toolbar_actions` and 
+:meth:`get_main_menu` method, it should be exactly the same object, to avoid
+shortcut confusion and reduce the number of status updates.
     """
 
-    backup_mechanism = BackupMechanism
     database_profile_wizard = database_selection.ProfileWizard
 
     name = 'Camelot'
@@ -121,6 +120,20 @@ methods :
 
     database_selection = False
 
+    #
+    # actions that will be shared between the toolbar and the main menu
+    #
+    change_row_actions = [ list_action.ToFirstRow(),
+                           list_action.ToPreviousRow(),
+                           list_action.ToNextRow(),
+                           list_action.ToLastRow(), ]
+    edit_actions = [ list_action.OpenNewView(),
+                     list_action.DeleteSelection(),
+                     list_action.DuplicateSelection(),]
+    help_actions = [ application_action.ShowHelp(), ]
+    export_actions = [ list_action.PrintPreview(),
+                       list_action.ExportSpreadsheet() ]
+    
     def __init__(self):
         """Construct an ApplicationAdmin object and register it as the 
         prefered ApplicationAdmin to use througout the application"""
@@ -156,6 +169,14 @@ methods :
                  Section( _('Configuration'), self ),
                  ]
         
+    def get_application_admin( self ):
+        """Get the :class:`ApplicationAdmin` class of this application, this
+        method is here for compatibility with the :class:`ObjectAdmin`
+        
+        :return: this object itself
+        """
+        return self
+    
     def get_related_admin(self, cls):
         """Get the default :class:`camelot.admin.object_admin.ObjectAdmin` class
         for a specific class, return None, if not known.  The ObjectAdmin
@@ -200,8 +221,11 @@ methods :
          
         :return: a :class:`PyQt4.QtGui.QWidget`
         """
+        from camelot.admin.action.application_action import ApplicationActionGuiContext
         from camelot.view.mainwindow import MainWindow
-        mainwindow = MainWindow(self)
+        gui_context = ApplicationActionGuiContext()
+        gui_context.admin = self
+        mainwindow = MainWindow( gui_context )
         shortcut_versions = QtGui.QShortcut(
             QtGui.QKeySequence( QtCore.Qt.CTRL+QtCore.Qt.ALT+QtCore.Qt.Key_V ),
             mainwindow
@@ -230,11 +254,87 @@ methods :
 
     def get_actions(self):
         """
-        :return: a list of :class:`camelot.admin.application_action.ApplicationAction` objects
-            that should be added to the menu and the icon bar for this application
+        :return: a list of :class:`camelot.admin.action.base.Action` objects
+            that should be displayed on the desktop of the user.
         """
         return []
+    
+    def get_related_toolbar_actions( self, toolbar_area, direction ):
+        """Specify the toolbar actions that should appear by default on every
+        OneToMany editor in the application.
+        
+        :param toolbar_area: the position of the toolbar
+        :param direction: the direction of the relation : 'onetomany' or 
+            'manytomany'
+        :return: a list of :class:`camelot.admin.action.base.Action` objects
+        """
+        if toolbar_area == Qt.RightToolBarArea and direction == 'onetomany':
+            return [ list_action.AddNewObject(),
+                     list_action.DeleteSelection(),
+                     list_action.DuplicateSelection(),
+                     list_action.ExportSpreadsheet(), ]
+        if toolbar_area == Qt.RightToolBarArea and direction == 'manytomany':
+            return [ list_action.AddExistingObject(),
+                     list_action.RemoveSelection(),
+                     list_action.ExportSpreadsheet(), ]
+        
+    def get_form_actions( self ):
+        """Specify the action buttons that should appear on each form in the
+        application.  
+        The :meth:`camelot.admin.object_admin.ObjectAdmin.get_form_actions`
+        method will call this method and prepend the result to the actions
+        of that specific form.
+        
+        :return: a list of :class:`camelot.admin.action.base.Action` objects
+        """
+        return []
+    
+    def get_main_menu( self ):
+        """
+        :return: a list of :class:`camelot.admin.menu.Menu` objects, or None if 
+            there should be no main menu
+        """
+        from camelot.admin.menu import Menu
 
+        return [ Menu( _('&File'),
+                       [ application_action.Backup(),
+                         application_action.Restore(),
+                         None,
+                         Menu( _('Export To'),
+                               self.export_actions ),
+                         Menu( _('Import From'),
+                               [list_action.ImportFromFile()] ),
+                         None,
+                         application_action.Exit(),
+                         ] ),
+                 Menu( _('&Edit'),
+                       self.edit_actions + [
+                        None,
+                        list_action.SelectAll(),
+                        None,
+                        list_action.ReplaceFieldContents(),   
+                        ]),
+                 Menu( _('View'),
+                       [ application_action.Refresh(),
+                         Menu( _('Go To'), self.change_row_actions) ] ),
+                 Menu( _('&Help'),
+                       self.help_actions + [
+                         application_action.ShowAbout() ] )
+                 ]
+    
+    def get_toolbar_actions( self, toolbar_area ):
+        """
+        :param toolbar_area: an instance of :class:`Qt.ToolBarArea` indicating
+            where the toolbar actions will be positioned
+            
+        :return: a list of :class:`camelot.admin.action.base.Action` objects
+            that should be displayed on the toolbar of the application.  return
+            None if no toolbar should be created.
+        """
+        if toolbar_area == Qt.TopToolBarArea:
+            return self.edit_actions + self.change_row_actions + \
+                   self.export_actions + self.help_actions
+    
     def get_name(self):
         """
         :return: the name of the application, by default this is the class
@@ -254,12 +354,29 @@ methods :
     def get_splashscreen(self):
         """:return: a :class:`PyQt4.QtGui.QPixmap` to be used as splash screen"""
         from camelot.view.art import Pixmap
-        return Pixmap('splashscreen.png').getQPixmap()
+        qpm = Pixmap('splashscreen.png').getQPixmap()
+        img = qpm.toImage()
+        # support transparency
+        if not qpm.mask(): 
+            if img.hasAlphaBuffer(): bm = img.createAlphaMask() 
+            else: bm = img.createHeuristicMask() 
+            qpm.setMask(bm) 
+        return qpm
 
     def get_organization_name(self):
+        """
+        :return: a string with the name of the organization that wrote the
+            application. By default returns the :attr:`ApplicationAdmin.author`
+            attribute.
+        """
         return self.author
 
     def get_organization_domain(self):
+        """
+        :return: a string with the domain name of the organization that wrote the
+            application. By default returns the :attr:`ApplicationAdmin.domain`
+            attribute.
+        """
         return self.domain
 
     def get_help_url(self):
@@ -268,40 +385,10 @@ methods :
         if self.help_url:
             return QUrl( self.help_url )
 
-    def get_whats_new(self):
-        """:return: a widget that has a show() method """
-        return None
-
-    def get_affiliated_url(self):
-        """:return: a :class:`PyQt4.QtCore.QUrl` pointing to an affiliated webpage
-
-        When this method returns a QUrl, an additional item will be available
-        in the 'Help' menu, when clicked the system browser will be opened
-        an pointing to this url.
-
-        This can be used to connect the user to a website that is used a lot
-        in the organization, but hard to remember.
-        """
-        from PyQt4.QtCore import QUrl
-        if self.application_url:
-            return QUrl( self.application_url )
-
-    def get_remote_support_url(self):
-        """:return: a :class:`PyQt4.QtCore.QUrl` pointing to a page to get remote support
-
-        When this method returns a QUrl, an additional item will be available
-        in the 'Help' menu, when clicked the system browser will be opened
-        an pointing to this url.
-
-        This can be used to connect the user to services like logmein.com, an
-        online ticketing system or others.
-        """
-        return None
-
     def get_stylesheet(self):
         """
-        :return: a string with the qt stylesheet to be used for this application as a string
-        or None if no stylesheet needed.
+        :return: a string with the content of a qt stylesheet to be used for 
+        this application as a string or None if no stylesheet needed.
 
         Camelot comes with a couple of default stylesheets :
 
@@ -494,13 +581,3 @@ methods :
         from camelot.core.view.field_attributes import \
             _sqlalchemy_to_python_type_
         return _sqlalchemy_to_python_type_[type_](field)
-
-    def backup(self, main_window):
-        from camelot.view.wizard.backup import BackupWizard
-        wizard = BackupWizard(self.backup_mechanism, main_window)
-        wizard.exec_()
-
-    def restore(self, main_window):
-        from camelot.view.wizard.backup import RestoreWizard
-        wizard = RestoreWizard(self.backup_mechanism, main_window)
-        wizard.exec_()
