@@ -27,6 +27,7 @@
 import logging
 logger = logging.getLogger('camelot.view.object_admin')
 
+from camelot.admin.action.form_action import CloseForm
 from camelot.view.model_thread import gui_function, model_function
 from camelot.view.controls.tableview import TableView
 from camelot.core.utils import ugettext as _
@@ -50,7 +51,7 @@ class FieldAttributesList(list):
 DYNAMIC_FIELD_ATTRIBUTES = FieldAttributesList(['tooltip', 'color', 'background_color',
                                                 'editable', 'choices',
                                                 'prefix', 'suffix', 'arrow',
-                                                'new_message', 'default',
+                                                'new_message',
                                                 'precision'])
 
 
@@ -126,6 +127,12 @@ be specified using the verbose_name attribute.
 
 **Behaviour**
 
+.. attribute:: form_close_action
+
+    The action triggered when the form window is closed.  By default this is the
+    :class:`camelot.admin.action.form_action.CloseForm` action, which validates
+    the form and allows the user to discard the changes when the form is invalid.
+    
 .. attribute:: save_mode
 
     Specifies when the data should be send from the view to the model and flushed
@@ -157,6 +164,10 @@ be specified using the verbose_name attribute.
 
         class Admin(EntityAdmin):
             form_actions = [('Foo', lamda o_getter:print 'foo')]
+            
+.. attribute:: related_toolbar_actions
+
+    list of actions that appear in the toolbar of a OneToMany editor.
 
 **Field attributes**
 
@@ -206,6 +217,7 @@ be specified using the verbose_name attribute.
 
     The QWidget class to be used when a table view is needed
     """
+    
     verbose_name = None
     verbose_name_plural = None
     list_display = []
@@ -215,16 +227,16 @@ be specified using the verbose_name attribute.
     model = CollectionProxy
     fields = []
     form_display = []
+    form_close_action = CloseForm()
     list_filter = []
     list_charts = []
     list_actions = []
-    list_size = (600, 400)
+    list_size = (600, 600)
     form_size = (700, 500)
     form_actions = []
     field_attributes = {}
     form_state = None
     icon = None # Default
-    
     #
     # Behavioral attributes
     # 
@@ -309,13 +321,29 @@ be specified using the verbose_name attribute.
         return _('Are you sure you want to delete this')
 
     @model_function
-    def get_form_actions(self, entity):
-        """
-        :return: a list of FormAction objects
+    def get_form_actions( self, obj ):
+        """Specify the list of action buttons that should appear on the side
+        of the form view.
+        
+        :param obj: the object displayed in the form
+        :return: a list of :class:`camelot.admin.action.base.Action` objects
         """
+        app_admin = self.get_application_admin()
         from camelot.admin.action.form_action import structure_to_form_actions
-        return structure_to_form_actions( self.form_actions )
+        return app_admin.get_form_actions() + structure_to_form_actions( self.form_actions )
 
+    def get_related_toolbar_actions( self, toolbar_area, direction ):
+        """Specify the toolbar actions that should appear in a OneToMany editor.
+        
+        :param toolbar_area: the position of the toolbar
+        :param direction: the direction of the relation : 'onetomany' or 
+            'manytomany'
+            
+        :return: a list of :class:`camelot.admin.action.base.Action` objects
+        """
+        app_admin = self.get_application_admin()
+        return app_admin.get_related_toolbar_actions( toolbar_area, direction )
+    
     @model_function
     def get_list_actions(self):
         return self.list_actions
@@ -371,7 +399,6 @@ be specified using the verbose_name attribute.
         """deprecated : use get_related_admin"""
         return self.get_related_admin(entity)
 
-
     def get_static_field_attributes(self, field_names):
         """
         Convenience function to get all the field attributes
@@ -405,7 +432,16 @@ be specified using the verbose_name attribute.
         :return: [{field_attribute_name:field_attribute_value, ...}, {}, ...]
 
         The returned list has the same order than the requested
-        field_names.
+        field_names.  A reimplementation of this method can look like::
+        
+        def get_dynamic_field_attributes(self, obj, field_names):
+            for field_attributes in super( MyAdmin, self ).get_dynamic_field_attributes(obj, field_names):
+                if obj.status == 'finished':
+                    field_attributes['editable'] = True
+                else:
+                    field_attributes['editable'] = False
+                yield field_attributes
+                
         """
         for field_name in field_names:
             field_attributes = self.get_field_attributes(field_name)
@@ -413,6 +449,11 @@ be specified using the verbose_name attribute.
             for name, value in field_attributes.items():
                 if name not in DYNAMIC_FIELD_ATTRIBUTES:
                     continue
+                if name in ('default',):
+                    # the default value of a field is not needed in the GUI,
+                    # and the continuous evaluation of it might be expensive,
+                    # as it might be the max of a column
+                    continue
                 if callable(value):
                     return_value = None
                     try:
@@ -530,7 +571,15 @@ be specified using the verbose_name attribute.
         return [(field, self.get_field_attributes(field))
                 for field in self.list_display]
 
+    def get_validator( self ):
+        """Get a validator object
+        
+        :return: a :class:`camelot.admin.validator.object_validator.Validator`
+        """
+        return self.validator( self )
+        
     def create_validator(self, model):
+        """deprecated"""
         return self.validator(self, model)
 
     @model_function
@@ -547,6 +596,14 @@ be specified using the verbose_name attribute.
         ]
         return fields_and_attributes
 
+    def get_application_admin( self ):
+        """Provide access to the :class:`ApplicationAdmin`
+        
+        :return: the :class:`camelot.admin.application_admin.ApplicationAdmin`
+            object for the application.
+        """
+        return self.app_admin.get_application_admin()
+    
     @model_function
     def get_all_fields_and_attributes(self):
         """A dictionary of (field_name:field_attributes) for all fields that can
@@ -594,7 +651,6 @@ be specified using the verbose_name attribute.
         self._apply_form_state( form )
         return form
 
-    # simply copied from EntityAdmin
     def set_defaults(self, object_instance, include_nullable_fields=True):
         """Set the defaults of an object
         :param include_nullable_fields: also set defaults for nullable fields, depending
@@ -602,6 +658,10 @@ be specified using the verbose_name attribute.
         to None
         """
         from sqlalchemy.schema import ColumnDefault
+        
+        if self.is_deleted( object_instance ):
+            return False
+        
         for field, attributes in self.get_fields():
             has_default = False
             try:
@@ -615,7 +675,9 @@ be specified using the verbose_name attribute.
                 # set already
                 #
                 value = attributes['getter'](object_instance)
-                if value!=None: # False is a legitimate value for Booleans
+                if value not in (None, []):
+                    # False is a legitimate value for Booleans, but a 
+                    # one-to-many field might have a default value as well
                     continue
                 if isinstance(default, ColumnDefault):
                     default_value = default.execute()
@@ -693,8 +755,8 @@ be specified using the verbose_name attribute.
         its underlying collection upon creation and removed from it upon
         discarding.
         """
-        from PyQt4 import QtGui, QtCore
-        from camelot.view.controls.view import AbstractView
+        from PyQt4 import QtCore
+        from camelot.view.controls.formview import FormView
         from camelot.view.model_thread import post
 
         class NewObjectCollectionProxy( CollectionProxy ):
@@ -744,28 +806,21 @@ be specified using the verbose_name attribute.
 
         validator = admin.create_validator(model)
 
-        class NewForm(AbstractView):
+        class NewView( FormView ):
 
             entity_created_signal = QtCore.pyqtSignal(object)
 
             def __init__(self, parent):
-                AbstractView.__init__(self, parent)
-                self.widget_layout = QtGui.QVBoxLayout()
-                self.widget_layout.setContentsMargins(0, 0, 0, 0)
-                title = _('New')
-                index = 0
-                self.form_view = admin.create_form_view(
-                    title, model, index, parent
-                )
-                self.widget_layout.insertWidget(0, self.form_view)
-                self.setLayout(self.widget_layout)
-                self.validate_before_close = True
+                super( NewView, self).__init__( title = _('New'), 
+                                                admin = admin, 
+                                                model = model, 
+                                                index = 0)
+
                 #
                 # every time data has been changed, it could become valid,
                 # when this is the case, it should be propagated
                 #
                 model.dataChanged.connect( self.dataChanged )
-                self.form_view.title_changed_signal.connect( self.change_title )
 
             def emit_if_valid(self, valid):
                 if valid:
@@ -783,56 +838,7 @@ be specified using the verbose_name attribute.
 
                 post(validate, self.emit_if_valid)
 
-            def showMessage(self, valid):
-                self.emit_if_valid(valid)
-                form = self.form_view.findChild(QtGui.QWidget, 'form' )
-                if not valid and form:
-                    row = 0
-                    reply = validator.validityDialog(row, self).exec_()
-                    if reply == QtGui.QMessageBox.Discard:
-                        # clear mapping to prevent data being written again to
-                        # the model, after we reverted the row
-                        form.clear_mapping()
-                        model.expunge()
-                        self.validate_before_close = False
-                        self.close()
-                else:
-                    self.validate_before_close = False
-                    self.close()
-
-            def validateClose(self):
-                logger.debug(
-                    'validate before close : %s' %
-                    self.validate_before_close
-                )
-                form = self.form_view.findChild(QtGui.QWidget, 'form' )
-                if self.validate_before_close:
-                    form.submit()
-                    logger.debug(
-                        'unflushed rows : %s' %
-                        str(model.hasUnflushedRows())
-                    )
-                    if model.hasUnflushedRows():
-
-                        def validate_and_flush():
-                            valid = validator.isValid(0)
-                            if valid:
-                                admin.flush( model.get_new_object() )
-                            return valid
-
-                        post(validate_and_flush, self.showMessage)
-                        return False
-                    else:
-                        return True
-                return True
-
-            def closeEvent(self, event):
-                if self.validateClose():
-                    event.accept()
-                else:
-                    event.ignore()
-
-        form = NewForm(parent)
+        form = NewView( parent )
         admin._apply_form_state( form )
         if hasattr(admin, 'form_size'):
             form.setMinimumSize(admin.form_size[0], admin.form_size[1])
