@@ -375,7 +375,6 @@ class Party( Entity ):
     def name( self ):
         return ''
 
-    @ColumnProperty
     def email( self ):
 
         cm = ContactMechanism
@@ -385,8 +384,9 @@ class Party( Entity ):
                           whereclause = and_( pcm.table.c.party_id == self.id,
                                               cm.table.c.mechanism.like( ( u'email', u'%' ) ) ),
                           from_obj = [cm.table.join( pcm.table )] ).limit(1)
+    
+    email = ColumnProperty( email, deferred = True )
 
-    @ColumnProperty
     def phone( self ):
 
         cm = ContactMechanism
@@ -396,8 +396,9 @@ class Party( Entity ):
                           whereclause = and_( pcm.table.c.party_id == self.id,
                                               cm.table.c.mechanism.like( ( u'phone', u'%' ) ) ),
                           from_obj = [cm.table.join( pcm.table )] ).limit(1)
+    
+    phone = ColumnProperty( phone, deferred = True )
 
-    @ColumnProperty
     def fax( self ):
 
         cm = ContactMechanism
@@ -408,6 +409,8 @@ class Party( Entity ):
                                               cm.table.c.mechanism.like( ( u'fax', u'%' ) ) ),
                           from_obj = [cm.table.join( pcm.table )] ).limit(1)
     
+    fax = ColumnProperty( fax, deferred = True )
+    
     #
     # Create virtual properties for email and phone that can
     # get and set a contact mechanism for the party
@@ -448,7 +451,6 @@ class Party( Entity ):
     contact_mechanisms_fax = property(_get_contact_mechanisms_fax,
                                       _set_contact_mechanism_fax)
 
-    @ColumnProperty
     def full_name( self ):
         aliased_organisation = Organization.table.alias( 'organisation_alias' )
         aliased_person = Person.table.alias( 'person_alias' )
@@ -459,6 +461,8 @@ class Party( Entity ):
                                       sql.select( [aliased_organisation.c.name],
                                                  whereclause = and_( aliased_party.c.id == self.id ),
                                                  from_obj = [aliased_party.join( aliased_organisation, aliased_organisation.c.party_id == aliased_party.c.id )] ).limit( 1 ).as_scalar() )
+    
+    full_name = ColumnProperty( full_name, deferred=True )
 
     class Admin( EntityAdmin ):
         verbose_name = _('Party')
@@ -467,6 +471,7 @@ class Party( Entity ):
         list_search = ['full_name']
         list_filter = ['categories.name']
         form_display = ['addresses', 'contact_mechanisms', 'shares', 'directed_organizations']
+        form_size = (700, 700)
         field_attributes = dict(addresses = {'admin':AddressAdmin},
                                 contact_mechanisms = {'admin':PartyPartyContactMechanismAdmin},
                                 suppliers = {'admin':SupplierCustomer.SupplierAdmin},
@@ -557,7 +562,10 @@ class Organization( Party ):
         verbose_name = _( 'Organization' )
         verbose_name_plural = _( 'Organizations' )
         list_display = ['name', 'tax_id', 'contact_mechanisms_email', 'contact_mechanisms_phone']
-        form_display = TabForm( [( _('Basic'), Form( ['name', 'tax_id', 'addresses', 'contact_mechanisms'] ) ),
+        form_display = TabForm( [( _('Basic'), Form( [ 'name', 'contact_mechanisms_email', 
+                                                       'contact_mechanisms_phone', 
+                                                       'contact_mechanisms_fax', 'tax_id', 
+                                                       'addresses', 'contact_mechanisms'] ) ),
                                 ( _('Employment'), Form( ['employees'] ) ),
                                 ( _('Customers'), Form( ['customers'] ) ),
                                 ( _('Suppliers'), Form( ['suppliers'] ) ),
@@ -565,6 +573,7 @@ class Organization( Party ):
                                 ( _('Branding'), Form( ['logo'] ) ),
                                 ( _('Category and Status'), Form( ['categories', 'status'] ) ),
                                 ] )
+        field_attributes = dict( Party.Admin.field_attributes )
 
 Organization = documented_entity()( Organization )
 
@@ -647,7 +656,7 @@ class Person( Party ):
                                                                   'contact_mechanisms_email',
                                                                   'contact_mechanisms_phone',
                                                                   'contact_mechanisms_fax'] ),
-                                                          Form( ['picture', ] ),
+                                                                [WidgetOnlyForm('picture'), ],
                                                          ] ),
                                                          'comment', ], scrollbars = False ) ),
                                 ( _('Official'), Form( ['birthdate', 'social_security_number', 'passport_number',
