@@ -1,6 +1,6 @@
 #  ============================================================================
 #
-#  Copyright (C) 2007-2010 Conceptive Engineering bvba. All rights reserved.
+#  Copyright (C) 2007-2011 Conceptive Engineering bvba. All rights reserved.
 #  www.conceptive.be / project-camelot@conceptive.be
 #
 #  This file is part of the Camelot Library.
@@ -37,7 +37,7 @@ be able to restore their state
 __metadata__ = metadata
 
 from camelot.core.utils import ugettext_lazy as _
-from camelot.view.elixir_admin import EntityAdmin
+from camelot.admin.entity_admin import EntityAdmin
 import datetime
 
 
@@ -106,3 +106,4 @@ class Create( Memento ):
         verbose_name = _('Create')
         verbose_name_plural = _('Creates')
 
+
