@@ -1,6 +1,6 @@
 #  ============================================================================
 #
-#  Copyright (C) 2007-2010 Conceptive Engineering bvba. All rights reserved.
+#  Copyright (C) 2007-2011 Conceptive Engineering bvba. All rights reserved.
 #  www.conceptive.be / project-camelot@conceptive.be
 #
 #  This file is part of the Camelot Library.
@@ -51,7 +51,7 @@ class VirtualAddress(types.TypeDecorator):
     eg: ``('email','project-camelot@conceptive.be')`` is stored as
     ``email://project-camelot@conceptive.be``
   
-    .. image:: ../_static/virtualaddress_editor.png
+    .. image:: /_static/virtualaddress_editor.png
     """
     
     impl = types.Unicode
@@ -102,7 +102,7 @@ class Code(types.TypeDecorator):
   
     eg: ``['08', 'AB']`` is stored as ``08.AB``
     
-    .. image:: ../_static/editors/CodeEditor_editable.png
+    .. image:: /_static/editors/CodeEditor_editable.png
     """
     
     impl = types.Unicode
@@ -162,7 +162,7 @@ class Rating(types.TypeDecorator):
       title = Field(Unicode(60), required=True)
       rating = Field(camelot.types.Rating())
       
-  .. image:: ../_static/editors/StarEditor_editable.png
+  .. image:: /_static/editors/StarEditor_editable.png
 """
     
     impl = types.Integer
@@ -171,7 +171,7 @@ class RichText(types.TypeDecorator):
     """RichText fields are unlimited text fields which contain html.  The html will be
   rendered in a rich text editor.  
   
-    .. image:: ../_static/editors/RichTextEditor_editable.png
+    .. image:: /_static/editors/RichTextEditor_editable.png
 """
     
     impl = types.UnicodeText
@@ -194,16 +194,22 @@ used too much memory, so now it's implemented using QT.
         
 class Color(types.TypeDecorator):
     """The Color field returns and accepts tuples of the form (r,g,b,a) where
-  r,g,b,a are integers between 0 and 255. The color is stored as an hexadecimal
-  string of the form AARRGGBB into the database, where AA is the transparency, 
-  RR is red, GG is green BB is blue::
+r,g,b,a are integers between 0 and 255. The color is stored as an hexadecimal
+string of the form AARRGGBB into the database, where AA is the transparency, 
+RR is red, GG is green BB is blue::
   
     class MovieType(Entity):
-      color = Field(camelot.types.Color())
+        color = Field(camelot.types.Color())
 
-  .. image:: ../_static/editors/ColorEditor_editable.png  
+.. image:: /_static/editors/ColorEditor_editable.png  
   
-  The colors are stored in the database as strings 
+The colors are stored in the database as strings.
+  
+Use::
+    
+    QColor(*color) 
+    
+to convert a color tuple to a QColor.
     """
     
     impl = types.Unicode
@@ -258,7 +264,7 @@ class Enumeration(types.TypeDecorator):
       state = Field(camelot.types.Enumeration([(1,'planned'), (2,'recording'), (3,'finished'), (4,'canceled')]), 
                                               index=True, required=True, default='planning')
   
-  .. image:: ../_static/editors/ChoicesEditor_editable.png  
+  .. image:: /_static/editors/ChoicesEditor_editable.png  
   
   If None should be a possible value of the enumeration, add (None, None) to the list of
   possible enumerations.  None will be presented as empty in the GUI.
@@ -289,6 +295,7 @@ class Enumeration(types.TypeDecorator):
                     return impl_processor(value)
                 except KeyError, e:
                     logger.error('could not process enumeration value %s, possible values are %s'%(value, u', '.join(list(self._string_to_int.keys()))), exc_info=e)
+                    raise
             else:
                 impl_processor(value)
                         
@@ -310,26 +317,51 @@ class Enumeration(types.TypeDecorator):
                     return self._int_to_string[value]
                 except KeyError, e:
                     logger.error('could not process %s'%value, exc_info=e)
+                    raise
                 
         return processor
     
 class File(types.TypeDecorator):
     """Sqlalchemy column type to store files.  Only the location of the file is stored
     
-  This column type accepts and returns a StoredFile, and stores them in the directory
-  specified by settings.CAMELOT_MEDIA_ROOT.  The name of the file is stored as a string in
-  the database.  A subdirectory upload_to can be specified::
+  This column type accepts and returns a StoredFile. The name of the file is 
+  stored as a string in the database.  A subdirectory upload_to can be specified::
   
     class Movie(Entity):
       script = Field(camelot.types.File(upload_to='script'))
       
-  .. image:: ../_static/editors/FileEditor_editable.png
+  .. image:: /_static/editors/FileEditor_editable.png
+  
+  Retrieving the actual storage from a File field can be a little cumbersome.
+  The easy way is taking it from the field attributes, in which it will be
+  put by default.  If no field attributes are available at the location where
+  the storage is needed, eg in some function doing document processing, one 
+  needs to go through SQLAlchemy to retrieve it.
+  
+  For an 'task' object  with a File field named 'document', the
+  storage can be retrieved::
+  
+      from sqlalchemy import orm
+      
+      task_mapper = orm.object_mapper( task )
+      document_property = task_mapper.get_property('document')
+      storage = document_property.columns[0].type.storage
+      
     """
     
     impl = types.Unicode
     stored_file_implementation = StoredFile
     
     def __init__(self, max_length=100, upload_to='', storage=Storage, **kwargs):
+        """
+        :param max_length: the maximum length of the name of the file that will
+        be saved in the database.
+        
+        :param upload_to: a subdirectory in the Storage, in which the the file
+        should be stored.
+        
+        :param storage: an alternative storage to use for this field.
+        """
         self.max_length = max_length
         self.storage = storage(upload_to, self.stored_file_implementation)
         types.TypeDecorator.__init__(self, length=max_length, **kwargs)
@@ -369,14 +401,15 @@ class Image(File):
     """Sqlalchemy column type to store images
     
   This column type accepts and returns a StoredImage, and stores them in the directory
-  specified by settings.MEDIA_ROOT.  The name of the file is stored as a string in
+  specified by settings.CAMELOT_MEDIA_ROOT.  The name of the file is stored as a string in
   the database.
   
   The Image field type provides the same functionallity as the File field type, but
   the files stored should be images.
   
-  .. image:: ../_static/editors/ImageEditor_editable.png
+  .. image:: /_static/editors/ImageEditor_editable.png
     """
   
     stored_file_implementation = StoredImage
 
+
