@@ -22,21 +22,27 @@
 #
 #  ============================================================================
 
-from change_object import ChangeObject, ChangeObjects
-from gui import OpenFormView, Refresh, ShowChart, ShowPixmap
+from backup import SelectBackup, SelectRestore
+from change_object import ChangeField, ChangeObject, ChangeObjects
+from gui import ( CloseView, MessageBox, OpenFormView, Refresh, ShowChart, 
+                  ShowPixmap )
 from open_file import ( OpenFile, OpenStream, 
                         OpenString, OpenJinjaTemplate, WordJinjaTemplate )
 from orm import CreateObject, DeleteObject, FlushSession, UpdateObject
 from print_preview import PrintHtml, PrintPreview, PrintJinjaTemplate
 from select_file import SelectFile
+from select_object import SelectObject
 from update_progress import UpdateProgress
 
 __all__ = [
+    ChangeField.__name__,
     ChangeObject.__name__,
     ChangeObjects.__name__,
+    CloseView.__name__,
     CreateObject.__name__,
     DeleteObject.__name__,
     FlushSession.__name__,
+    MessageBox.__name__,
     OpenFile.__name__,
     OpenFormView.__name__,
     OpenJinjaTemplate.__name__,
@@ -46,7 +52,10 @@ __all__ = [
     PrintJinjaTemplate.__name__,
     PrintPreview.__name__,
     Refresh.__name__,
+    SelectBackup.__name__,
     SelectFile.__name__,
+    SelectObject.__name__,
+    SelectRestore.__name__,
     ShowChart.__name__,
     ShowPixmap.__name__,
     UpdateObject.__name__,
