@@ -25,8 +25,7 @@ from PyQt4 import QtGui, QtCore
 from PyQt4.QtCore import Qt
 
 from customdelegate import CustomDelegate, DocumentationMetaclass
-from camelot.view.controls import editors
-from camelot.view.art import Icon
+from camelot.view.controls.editors.smileyeditor import SmileyEditor, default_icons
 
 class SmileyDelegate(CustomDelegate):
     """Delegate for Smiley's
@@ -34,22 +33,22 @@ class SmileyDelegate(CustomDelegate):
   
     __metaclass__ = DocumentationMetaclass
     
-    editor = editors.SmileyEditor
+    editor = SmileyEditor
   
-    def __init__(self, parent, editable=True,  **kwargs):
+    def __init__(self, parent, editable=True,  icons=default_icons, **kwargs):
         CustomDelegate.__init__(self,
                                 parent=parent,
                                 editable=editable,
-                                maximum=1,
+                                icons=icons,
                                 **kwargs)
+        self.icons_by_name = dict(icons)
         
     def paint(self, painter, option, index):
         painter.save()
-        img = index.model().data(index, Qt.DisplayRole).toString()
+        icon_name = unicode(index.model().data(index, Qt.DisplayRole).toString())
         
         background_color = QtGui.QColor(index.model().data(index, Qt.BackgroundRole))
         
-        imgPath = 'tango/16x16/emotes/' + img + '.png'
         self.drawBackground(painter, option, index)
         rect = option.rect
         rect = QtCore.QRect(rect.left()+3, rect.top()+6, rect.width()-5, rect.height())
@@ -61,10 +60,11 @@ class SmileyDelegate(CustomDelegate):
                 painter.fillRect(option.rect, option.palette.window())
             else:
                 painter.fillRect(option.rect, background_color)
-          
-        icon = Icon(imgPath).getQPixmap()
-        QtGui.QApplication.style().drawItemPixmap(painter, rect, 1, icon)
-        rect = QtCore.QRect(rect.left()+20, rect.top(), rect.width(), rect.height())
+                
+        if icon_name:
+            pixmap = self.icons_by_name[icon_name].getQPixmap()
+            QtGui.QApplication.style().drawItemPixmap(painter, rect, 1, pixmap)
+
         painter.restore()
 
 
