@@ -198,7 +198,6 @@ class CollectionProxy( QtCore.QAbstractTableModel ):
                   collection_getter, 
                   columns_getter,
                   max_number_of_rows = 10, 
-                  edits = None, 
                   flush_changes = True,
                   cache_collection_proxy = None
                   ):
@@ -248,22 +247,23 @@ position in the query.
         self._columns = []
         self._static_field_attributes = []
         self._max_number_of_rows = max_number_of_rows
+        max_cache = 10 * self.max_number_of_rows
         if cache_collection_proxy:
-            self.display_cache = cache_collection_proxy.display_cache.shallow_copy( 10 * self.max_number_of_rows )
-            self.edit_cache = cache_collection_proxy.edit_cache.shallow_copy( 10 * self.max_number_of_rows )
-            self.attributes_cache = cache_collection_proxy.attributes_cache.shallow_copy( 10 * self.max_number_of_rows )
+            cached_entries = len( cache_collection_proxy.display_cache )
+            max_cache = max( cached_entries, max_cache )
+            self.display_cache = cache_collection_proxy.display_cache.shallow_copy( max_cache )
+            self.edit_cache = cache_collection_proxy.edit_cache.shallow_copy( max_cache )
+            self.attributes_cache = cache_collection_proxy.attributes_cache.shallow_copy( max_cache )
         else:        
-            self.display_cache = Fifo( 10 * self.max_number_of_rows )
-            self.edit_cache = Fifo( 10 * self.max_number_of_rows )
-            self.attributes_cache = Fifo( 10 * self.max_number_of_rows )
+            self.display_cache = Fifo( max_cache )
+            self.edit_cache = Fifo( max_cache )
+            self.attributes_cache = Fifo( max_cache )
         # The rows in the table for which a cache refill is under request
         self.rows_under_request = set()
         self._update_requests = list()
         # The rows that have unflushed changes
         self.unflushed_rows = set()
         self._sort_and_filter = SortingRowMapper()
-        # Set edits
-        self.edits = edits or []
         self.row_changed_signal.connect( self._emit_changes )
         self.rsh = get_signal_handler()
         self.rsh.connect_signals( self )
@@ -319,27 +319,6 @@ position in the query.
         rows = len( set( self.get_collection() ) )
         return rows
 
-    @gui_function
-    def revertRow( self, row ):
-        def create_refresh_entity( row ):
-
-            @model_function
-            def refresh_entity():
-                o = self._get_object( row )
-                self.admin.refresh( o )
-                return row, o
-
-            return refresh_entity
-
-        post( create_refresh_entity( row ), self._revert_row )
-
-    @QtCore.pyqtSlot(tuple)
-    @gui_function
-    def _revert_row(self, row_and_entity ):
-        row, entity = row_and_entity
-        self.handleRowUpdate( row )
-        self.rsh.sendEntityUpdate( self, entity )
-
     @gui_function
     def refresh( self ):
         post( self.getRowCount, self._refresh_content )
@@ -409,12 +388,13 @@ position in the query.
         """Handles the entity signal, indicating that the model is out of
         date"""
         self.logger.debug( 'received entity delete signal' )
-        #
-        # simply removing the entity from the collection might have
-        # undesirable effects.  eg when a form is pointing to this entity, 
-        # so instead update the entity
-        #
-        self.handle_entity_update( sender, entity )
+        if sender != self:
+            try:
+                row = self.display_cache.get_row_by_entity(entity)
+            except KeyError:
+                self.logger.debug( 'entity not in cache' )
+                return
+            self.remove_rows( [row], delete = False )
 
     @QtCore.pyqtSlot( object, object )
     def handle_entity_create( self, sender, entity ):
@@ -539,7 +519,7 @@ position in the query.
                 return QtCore.QVariant( QtCore.QSize( size, self._horizontal_header_height ) )
         else:
             if role == Qt.SizeHintRole:
-                if self.header_icon:
+                if self.header_icon != None:
                     return QtCore.QVariant( QtCore.QSize( self.iconSize.width() + 10,
                                                           self._vertical_header_height ) )
                 else:
@@ -547,8 +527,9 @@ position in the query.
                     return QtCore.QVariant( QtCore.QSize( QtGui.QFontMetrics( self._header_font ).size( Qt.TextSingleLine, str(self._rows) ).width() + 10, self._vertical_header_height ) )
             if role == Qt.DecorationRole:
                 return self.form_icon
-#      elif role == Qt.DisplayRole:
-#        return QtCore.QVariant()
+            elif role == Qt.DisplayRole:
+                if self.header_icon != None:
+                    return QtCore.QVariant( '' )
         return QtCore.QAbstractTableModel.headerData( self, section, orientation, role )
 
     @gui_function
@@ -570,7 +551,7 @@ position in the query.
         post(create_sort(column, order), self._refresh_content)
 
     @gui_function
-    def data( self, index, role ):
+    def data( self, index, role = Qt.DisplayRole):
         """:return: the data at index for the specified role
         This function will return ValueLoading when the data has not
         yet been fetched from the underlying model.  It will then send
@@ -612,7 +593,7 @@ position in the query.
         elif role == Qt.ToolTipRole:
             return QtCore.QVariant(self._get_field_attribute_value(index, 'tooltip'))
         elif role == Qt.BackgroundRole:
-            return QtCore.QVariant(self._get_field_attribute_value(index, 'background_color') or QtGui.QColor('White'))
+            return QtCore.QVariant(self._get_field_attribute_value(index, 'background_color') or QtCore.QVariant())
         elif role == Qt.UserRole:
             field_attributes = ProxyDict(self._static_field_attributes[index.column()])
             dynamic_field_attributes = self._get_row_data( index.row(), self.attributes_cache )[index.column()]
@@ -654,7 +635,6 @@ position in the query.
             attribute, field_attributes = self.getColumns()[column]
 
             from sqlalchemy.exc import DatabaseError
-            from sqlalchemy import orm
             new_value = value()
             self.logger.debug( 'set data for row %s;col %s' % ( row, column ) )
 
@@ -696,7 +676,7 @@ position in the query.
             # consider it changed anyway
             #
             direction = field_attributes.get( 'direction', None )
-            if direction in ( orm.interfaces.MANYTOMANY, orm.interfaces.ONETOMANY ):
+            if direction in ( 'manytomany', 'onetomany' ):
                 changed = True
             if changed:
                 # update the model
@@ -768,7 +748,6 @@ position in the query.
                 locker.unlock()
         return return_list
 
-
     def setData( self, index, value, role = Qt.EditRole ):
         """Value should be a function taking no arguments that returns the data to
         be set
@@ -1109,6 +1088,11 @@ position in the query.
 #      elixir.session.flush([history])
 #      self.rsh.sendEntityCreate(self, o)
         self._rows = rows + 1
+        #
+        # update the cache, so the object can be retrieved
+        #
+        columns = self.getColumns()
+        self._add_data( columns, rows, obj )
         self.endInsertRows()
         return self._rows
 
