@@ -1,6 +1,6 @@
 #  ============================================================================
 #
-#  Copyright (C) 2007-2010 Conceptive Engineering bvba. All rights reserved.
+#  Copyright (C) 2007-2011 Conceptive Engineering bvba. All rights reserved.
 #  www.conceptive.be / project-camelot@conceptive.be
 #
 #  This file is part of the Camelot Library.
@@ -38,7 +38,8 @@ LOGGER = logging.getLogger('remote_signals')
 
 from PyQt4 import QtCore
 
-from camelot.core.threading import synchronized
+#from camelot.core.threading import synchronized
+from camelot.core.conf import settings
 
 class SignalHandler(QtCore.QObject):
     """The signal handler connects multiple collection proxy classes to
@@ -48,11 +49,14 @@ class SignalHandler(QtCore.QObject):
     can inform other signal handlers on the network of the change.
     
     A couple of the methods of this thread are protected by a QMutex through
-    the synchronized decorator.  It appears that python/qt deqdlocks when the
+    the synchronized decorator.  It appears that python/qt deadlocks when the
     entity_update_signal is connected to and emitted at the same time.  This
     can happen when the user closes a window that is still building up (the
     CollectionProxies are being constructed and they connect to the signal
     handler).
+    
+    These deadlock issues are resolved in recent PyQt, so comment out the 
+    mutex stuff. (2011-08-12)
      """
 
     entity_update_signal = QtCore.pyqtSignal(object, object)
@@ -63,8 +67,7 @@ class SignalHandler(QtCore.QObject):
     
     def __init__(self):
         super(SignalHandler, self).__init__()
-        import settings
-        self._mutex = QtCore.QMutex()
+        #self._mutex = QtCore.QMutex()
         self.update_expression = re.compile(self.entity_update_pattern)
         if hasattr(settings, 'CAMELOT_SERVER') and settings.CAMELOT_SERVER:
             from stomp import stomp
@@ -76,7 +79,7 @@ class SignalHandler(QtCore.QObject):
             self.connection = None
             LOGGER.debug('not connected to a server')
             
-    @synchronized
+    #@synchronized
     def connect_signals(self, obj):
         """Connect the SignalHandlers its signals to the slots of obj, while
         the mutex is locked"""
@@ -122,7 +125,7 @@ class SignalHandler(QtCore.QObject):
         changed"""
         self.sendEntityUpdate(sender, entity, scope)
     
-    @synchronized        
+    #@synchronized        
     def sendEntityUpdate(self, sender, entity, scope='local'):
         """Call this method to inform the whole application an entity has 
         changed"""
@@ -131,17 +134,19 @@ class SignalHandler(QtCore.QObject):
         if self.connection and scope == 'remote':
             self.connection.send(str([entity.id]), destination='/topic/Camelot.Entity.%s.update'%entity.__class__.__name__)
         
-    @synchronized    
+    #@synchronized    
     def sendEntityDelete(self, sender, entity, scope='local'):
         """Call this method to inform the whole application an entity is 
         about to be deleted"""
+        self.entity_delete_signal.emit( sender, entity )
         if self.connection and scope == 'remote':
             self.connection.send(str([entity.id]), destination='/topic/Camelot.Entity.%s.delete'%entity.__class__.__name__)
             
-    @synchronized
+    #@synchronized
     def sendEntityCreate(self, sender, entity, scope='local'):
         """Call this method to inform the whole application an entity 
         was created"""
+        self.entity_create_signal.emit( sender, entity )
         if self.connection and scope == 'remote':
             self.connection.send(str([entity.id]), destination='/topic/Camelot.Entity.%s.create'%entity.__class__.__name__)
 
@@ -161,3 +166,4 @@ def has_signal_handler():
     """Request if the singleton signal handler was constructed"""
     return len(_signal_handler_)
 
+
