@@ -1,6 +1,6 @@
 #  ============================================================================
 #
-#  Copyright (C) 2007-2010 Conceptive Engineering bvba. All rights reserved.
+#  Copyright (C) 2007-2011 Conceptive Engineering bvba. All rights reserved.
 #  www.conceptive.be / project-camelot@conceptive.be
 #
 #  This file is part of the Camelot Library.
@@ -62,10 +62,9 @@ def create_entity_search_query_decorator(admin, text):
             elif issubclass(c.type.__class__, camelot.types.File):
                 pass
             elif issubclass(c.type.__class__, camelot.types.Code):
-                codes = text.split(c.type.separator)
-                arg = c.like(['%'] + codes + ['%'])
-                arg = sql.or_(arg, c.like(['%'] + codes))
-                arg = sql.or_(arg, c.like(codes + ['%']))
+                codes = [u'%%%s%%'%s for s in text.split(c.type.separator)]
+                codes = codes + ['%']*(len(c.type.parts) - len(codes))
+                arg = c.like( codes )
             elif issubclass(c.type.__class__, camelot.types.VirtualAddress):
                 arg = c.like(('%', '%'+text+'%'))
             elif issubclass(c.type.__class__, camelot.types.Image):
@@ -113,11 +112,11 @@ def create_entity_search_query_decorator(admin, text):
             path = column_name.split('.')
             target = admin.entity
             for path_segment in path:
-                mapper = orm.class_mapper(target)
-                property = mapper.get_property(path_segment, resolve_synonyms=True)
+                mapper = orm.class_mapper( target )
+                property = mapper.get_property( path_segment )
                 if isinstance(property, orm.properties.PropertyLoader):
                     joins.append(getattr(target, path_segment))
-                    target = property._get_target().class_
+                    target = property.mapper.class_
                 else:
                     append_column(property.columns[0])
                     #args.append(property.columns[0].like('%'+text+'%'))
@@ -142,3 +141,4 @@ def create_entity_search_query_decorator(admin, text):
 
         return create_query_decorator(joins, args)
 
+
