@@ -6,6 +6,7 @@ import unittest
 import os
 import time
 
+from camelot.core.utils import ugettext_lazy as _
 from camelot.test import ModelThreadTestCase, EntityViewsTest, SchemaTest
 from camelot.view.art import ColorScheme
 
@@ -714,13 +715,6 @@ class DelegateTest(ModelThreadTestCase):
         self.assertTrue(isinstance(editor, self.editors.DateTimeEditor))
         self.grab_delegate(delegate, DateTime, 'disabled')
 
-    def testEnumerationDelegate(self):
-        choices = [('a','A'), ('b','B')]
-        delegate = self.delegates.EnumerationDelegate(parent=None, choices=choices)
-        self.grab_delegate(delegate, 'a')
-        delegate = self.delegates.EnumerationDelegate(parent=None, choices=choices, editable=False)
-        self.grab_delegate(delegate, 'a', 'disabled')
-
     def testLocalFileDelegate(self):
         delegate = self.delegates.LocalFileDelegate(parent=None)
         self.grab_delegate(delegate, '/home/lancelot/quests.txt')
@@ -918,31 +912,40 @@ class FilterTest(ModelThreadTestCase):
 
     group_box_filter = filters.GroupBoxFilter('state')
     combo_box_filter = filters.ComboBoxFilter('state')
-    name_and_options = ('Organization', [('Nokia',None), ('Apple',None)])
+    test_data = filters.filter_data( name = _('Organization'),
+                                    default = 1,
+                                    options = [ filters.filter_option( name = 'Nokia',
+                                                                       value = 1,
+                                                                       decorator = None ),
+                                                filters.filter_option( name = 'Apple',
+                                                                       value = 2,
+                                                                       decorator = None ) ] )
 
     def test_group_box_filter(self):
-        self.grab_widget(self.group_box_filter.render(None, *self.name_and_options))
+        self.grab_widget( self.group_box_filter.render( self.test_data, None ) )
 
     def test_combo_box_filter(self):
-        self.grab_widget(self.combo_box_filter.render(None, *self.name_and_options))
+        self.grab_widget( self.combo_box_filter.render( self.test_data, None ) )
 
     def test_filter_list(self):
         from camelot.view.controls.filterlist import FilterList
-        items = [(self.group_box_filter, self.name_and_options),
-                 (self.combo_box_filter, self.name_and_options)]
-        filter_list = FilterList(items, parent=None)
-        self.grab_widget(filter_list)
+        items = [ ( self.group_box_filter, self.test_data ),
+                  ( self.combo_box_filter, self.test_data ) ]
+        filter_list = FilterList( items, parent=None)
+        self.grab_widget( filter_list )
 
     def test_filter_list_in_table_view(self):
         from camelot.view.controls.tableview import TableView
         from camelot.model.authentication import Person
         from camelot.admin.application_admin import ApplicationAdmin
+        from camelot.admin.action.base import GuiContext
+        gui_context = GuiContext()
         app_admin = ApplicationAdmin()
         person_admin = Person.Admin(app_admin, Person)
-        table_view = TableView(person_admin)
-        items = [(self.group_box_filter, self.name_and_options),
-                 (self.combo_box_filter, self.name_and_options)]
-        table_view.set_filters_and_actions((items, None))
+        table_view = TableView( gui_context, person_admin )
+        items = [ (self.group_box_filter, self.test_data ),
+                  (self.combo_box_filter, self.test_data ) ]
+        table_view.set_filters_and_actions( (items, None) )
 
 class ControlsTest(ModelThreadTestCase):
     """Test some basic controls"""
@@ -952,7 +955,10 @@ class ControlsTest(ModelThreadTestCase):
     def setUp(self):
         super(ControlsTest, self).setUp()
         from camelot_example.application_admin import MyApplicationAdmin
+        from camelot.admin.action.application_action import ApplicationActionGuiContext
         self.app_admin = MyApplicationAdmin()
+        self.gui_context = ApplicationActionGuiContext()
+        self.gui_context.admin = self.app_admin
 
     def wait_for_animation( self ):
         # wait a while to make sure all animations are finished
@@ -963,7 +969,10 @@ class ControlsTest(ModelThreadTestCase):
     def test_table_view(self):
         from camelot.view.controls.tableview import TableView
         from camelot.model.authentication import Person
-        widget = TableView(self.app_admin.get_entity_admin(Person))
+        from camelot.admin.action.base import GuiContext
+        gui_context = GuiContext()
+        widget = TableView( gui_context, 
+                            self.app_admin.get_entity_admin(Person) )
         self.grab_widget(widget)
 
     def test_navigation_pane(self):
@@ -977,9 +986,22 @@ class ControlsTest(ModelThreadTestCase):
 
     def test_main_window(self):
         from camelot.view.mainwindow import MainWindow
-        widget = MainWindow(self.app_admin)
+        widget = MainWindow( self.gui_context ) 
         self.wait_for_animation()
         self.grab_widget(widget)
+        
+    def test_reduced_main_window(self):
+        from camelot.view.mainwindow import MainWindow
+        from camelot_example.application_admin import MiniApplicationAdmin
+        from camelot.admin.action.application_action import ApplicationActionGuiContext
+        app_admin = MiniApplicationAdmin()
+        gui_context = ApplicationActionGuiContext()
+        gui_context.admin = app_admin
+        widget = MainWindow( gui_context )
+        widget.setStyleSheet( app_admin.get_stylesheet() )
+        widget.show()
+        self.wait_for_animation()
+        self.grab_widget( widget )     
 
     def test_status_bar(self):
         from camelot.view.controls.statusbar import StatusBar
